@@ -14,13 +14,14 @@ from transformers.utils import is_torch_npu_available
 
 from swift.llm import InferRequest, Template, TemplateMeta, get_model_tokenizer
 from swift.plugin import Metric
-from swift.utils import get_dist_setting, is_dist
+from swift.utils import get_dist_setting, get_logger, is_dist
 from ..protocol import (ChatCompletionResponse, ChatCompletionResponseChoice, ChatCompletionResponseStreamChoice,
                         ChatCompletionStreamResponse, ChatMessage, DeltaMessage, RequestConfig, random_uuid)
 from .infer_engine import InferEngine
 from .patch import patch_auto_config, patch_auto_tokenizer
 from .utils import AdapterRequest, InferStreamer, patch_npu_vllm, patch_vllm_memory_leak
 
+logger = get_logger()
 try:
     # After setting the environment variables, import vllm. This way of writing allows lint to pass.
     os.environ['VLLM_WORKER_MULTIPROC_METHOD'] = 'spawn'
@@ -129,6 +130,7 @@ class VllmEngine(InferEngine):
         enforce_eager: bool = False,
         limit_mm_per_prompt: Optional[Dict[str, Any]] = None,
         device: str = 'auto',
+        seed: Optional[int] = None,
         enable_lora: bool = False,
         max_loras: int = 1,
         max_lora_rank: int = 16,
@@ -158,10 +160,15 @@ class VllmEngine(InferEngine):
                 'The current version of VLLM does not support `limit_mm_per_prompt`. Please upgrade VLLM.')
         if 'enable_sleep_mode' in parameters:
             engine_kwargs['enable_sleep_mode'] = enable_sleep_mode
+        for key in ['seed']:
+            val = locals()[key]
+            if val is not None:
+                engine_kwargs[key] = val
 
         model_info = self.model_info
-        if self.config.architectures is None:
-            architectures = {'deepseek_vl2': ['DeepseekVLV2ForCausalLM']}[self.model_meta.model_type]
+        arch_mapping = {'deepseek_vl2': ['DeepseekVLV2ForCausalLM'], 'glm4v': ['GLM4VForCausalLM']}
+        if self.model_meta.model_type in arch_mapping:
+            architectures = arch_mapping[self.model_meta.model_type]
             engine_kwargs['hf_overrides'] = {'architectures': architectures}
         engine_args = engine_cls(
             model=self.model_dir,
@@ -183,7 +190,8 @@ class VllmEngine(InferEngine):
         self.engine_args = engine_args
         self.enable_lora = enable_lora
         if max_model_len is not None:
-            model_info.max_model_len = max_model_len
+            self.max_model_len = max_model_len
+            logger.info(f'Setting max_model_len: {max_model_len}')
 
     def _fix_vllm_bug(self) -> None:
         # fix vllm==0.4 bug (very slow)
@@ -224,6 +232,8 @@ class VllmEngine(InferEngine):
                         template_meta: TemplateMeta) -> None:
         stop_words = (request_config.stop or []) + (self.generation_config.stop or []) + template_meta.stop_words
         generation_config.stop = self._get_stop_words(stop_words)
+        # stop parameter is not effective in v1 engine (test version: vllm 0.8.5.post)
+        generation_config.stop_token_ids = self._get_stop_token_ids(stop_words)
 
     @staticmethod
     def _version_ge(base_version: str):
@@ -437,16 +447,17 @@ class VllmEngine(InferEngine):
             template.set_mode('vllm')
             batched_inputs, error_list = self._batch_encode(
                 infer_requests, template=template, strict=getattr(self, 'strict', True))
-            self.set_default_max_tokens(request_config, batched_inputs)
             request_id_list = []
             for i, inputs in enumerate(batched_inputs):
                 request_id = str(self._request_count)
                 request_id_list.append(request_id)
                 self._request_count += 1
-                generation_config = self._prepare_generation_config(request_config)
+                _request_config = deepcopy(request_config)
+                self.set_default_max_tokens(_request_config, inputs)
+                generation_config = self._prepare_generation_config(_request_config)
                 if generation_config.seed is not None:
                     generation_config.seed += i
-                self._add_stop_words(generation_config, request_config, template.template_meta)
+                self._add_stop_words(generation_config, _request_config, template.template_meta)
                 self._add_request(inputs, generation_config, request_id, adapter_request=adapter_request)
             prog_bar = tqdm(total=len(batched_inputs), dynamic_ncols=True, disable=not use_tqdm)
             outputs = {}
@@ -485,7 +496,7 @@ class VllmEngine(InferEngine):
                     for request_id, result in zip(request_id_list, outputs)
                 ]
                 self._update_metrics(res, metrics)
-                return res
+                return self._add_error_list(res, error_list)
 
     async def infer_async(
         self,
